==> haskell-yaml-0.8.17-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yaml/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.17
id: yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
key: yaml_BbJTt2NWP8rHaPVn0MXFmr
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    Please see the README.md file.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
exposed-modules:
    Text.Libyaml Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder
    Data.Yaml.Config Data.Yaml.Pretty Data.Yaml.Parser
    Data.Yaml.Include
hidden-modules: Data.Yaml.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.17
library-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.17
data-dir: /usr/share/arm-linux-ghc-7.10.3/yaml-0.8.17
hs-libraries: HSyaml-0.8.17-BbJTt2NWP8rHaPVn0MXFmr
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    enclosed-exceptions-1.0.1.1-178e95d86200c5f0616588d334587add
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.8.17.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yaml/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.17.1
id: yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
key: yaml_DBYcYVMG9RKHqHQw8Vnz1M
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    Please see the README.md file.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
exposed-modules:
    Text.Libyaml Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder
    Data.Yaml.Config Data.Yaml.Pretty Data.Yaml.Parser
    Data.Yaml.Include
hidden-modules: Data.Yaml.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.17.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.17.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/yaml-0.8.17.1
hs-libraries: HSyaml-0.8.17.1-DBYcYVMG9RKHqHQw8Vnz1M
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    enclosed-exceptions-1.0.1.1-178e95d86200c5f0616588d334587add
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
